@@ -15,7 +15,7 @@
 	int previousTrackIndexSelected;
 	NSDictionary *fileExtensionsToCodecsDictionary;
 	activeObjects objectToSaveTrack;
-	BOOL trackListUpToDate;
+	BOOL trackListIsUpToDate;
 }
 - (void)loadTracks;
 - (NJBTransactionResult *)downloadTrackList;
@@ -23,6 +23,6 @@
 - (void)copyTrackFromNJB:(Track *)track;
 - (void)replaceTrack:(Track *)replace withTrack:(Track *)new;
 - (void)writeTagToFile:(Track *)track;
-- (NJBTransactionResult *)uploadTrack:(Track *)track;
+- (BOOL)trackListIsUpToDate;
 
 @end
