@@ -68,6 +68,7 @@
 	[browser setAllowedExtensions:extensions];
 	[browser setBaseLocation:[preferences musicTabDir]];
 	
+	[njbTable setAllowedExtensions:extensions];
 	[njbTable setAutosaveName:PREF_KEY_MUSIC_TAB_TABLE];
 	[njbTable setAutosaveTableColumns:YES];
 }
@@ -241,6 +242,7 @@
 {
 	if (![theNJB isConnected])
 		return;
+		
 	NJBQueueItem *copyTrack = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(downloadTrack:) withObject:track];
 	[copyTrack setStatus:STATUS_DOWNLOADING_TRACK];
 	NSString *description = [NSString stringWithFormat:@"Downloading track '%@'", [track title]];
@@ -256,9 +258,11 @@
 	if ([preferences writeTagAfterCopy] && [track codec] == CODEC_MP3)
 	{
 		NJBQueueItem *writeTag = [[NJBQueueItem alloc] initWithTarget:self withSelector:@selector(writeTagToFile:) withObject:track];
-		[writeTag setRunInMainThread:NO];
+		// putting this to NO causes weird and wonderful crashes later on e.g. memory of the njb_t struct in theNJB getting overwritten...
+		// should be YES though (wasn't pre 0.23)
+		[writeTag setRunInMainThread:YES];
 		[writeTag setDisplayStatus:NO];
-		
+
 		[self addToQueue:copyTrack withSubItems:[NSArray arrayWithObjects:updatePlaylistsTab, writeTag, nil] withDescription:description];
 		[writeTag release];
 	}
@@ -579,10 +583,10 @@
 	NJBQueueItem *updatePlaylistsTab = [[NJBQueueItem alloc] initWithTarget:playlistsTab withSelector:@selector(updateTracks)];
 	[updatePlaylistsTab setRunInMainThread:NO];
 	[updatePlaylistsTab setDisplayStatus:NO];
-		
+	
 	NSString *description = [NSString stringWithFormat:@"Deleting track '%@'", [track title]];
 	[self addToQueue:deleteTrack withSubItems:[NSArray arrayWithObjects:removeFromAllTracks, updateTrackList, updatePlaylistsTab, nil] withDescription:description];
-		
+
 	[deleteTrack release];
 	[removeFromAllTracks release];
 	[updateTrackList release];
