@@ -43,6 +43,10 @@
 	[browser setTarget:self];
 	[browser setFileAction:@selector(fileSystemBrowserFileClick:)];
 	[browser setDirectoryAction:@selector(fileSystemBrowserDirectoryClick:)];
+	
+	// allow drag & drop
+	[njbTable registerDragAndDrop];
+	[njbTable disallowCopies];
 }
 
 /* makes a string into a legal filename
@@ -186,6 +190,7 @@
 	[deleteFromActiveObjectButton setEnabled:[self canDelete]];
 	[copyToNJBButton setEnabled:[self canCopyToNJB]];
 	[copyFromNJBButton setEnabled:[self canCopyFromNJB]];
+	[njbTable allowCopies];
 }
 
 /* disable transfer buttons
@@ -195,6 +200,7 @@
 	[deleteFromActiveObjectButton setEnabled:[self canDelete]];
 	[copyToNJBButton setEnabled:NO];
 	[copyFromNJBButton setEnabled:NO];
+	[njbTable disallowCopies];
 }
 
 /* get a list of all the files to copy to the NJB
@@ -333,4 +339,14 @@
 	[self menuDelete];
 }
 
+/* adds the item to fullItemArray and calls
+* searchNJBTable. To be run when new item added to
+* list.
+*/
+- (void)addToFullItemArray:(MyItem *)item
+{
+	[fullItemArray addObject:item];
+	[self searchNJBTable];
+}
+
 @end
