@@ -1,9 +1,5 @@
 #include <libnjb.h>
-#ifdef HAVE_GETOPT_H
 #include <getopt.h>
-#else
-#include <unistd.h>
-#endif
 
 static int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data)
 {
