@@ -1,9 +1,5 @@
 #include <libnjb.h>
-#ifdef HAVE_GETOPT_H
 #include <getopt.h>
-#else
-#include <unistd.h>
-#endif
 
 int main (int argc, char **argv)
 {
@@ -33,11 +29,6 @@ int main (int argc, char **argv)
     return 1;
   }
 
-  if ( n == 0 ) {
-    fprintf(stderr, "no NJB devices found\n");
-    return 0;
-  }
-
   njb = &njbs[0];
 
   if ( NJB_Open(njb) == -1 ) {
