@@ -5,7 +5,6 @@ int main (int argc, char **argv)
 {
 	njb_t njbs[NJB_MAX_DEVICES];
 	njb_t *njb;
-	njbid_t *njbid = NULL;
 	int i, n, opt, debug;
 	extern char *optarg;
 
@@ -23,20 +22,23 @@ int main (int argc, char **argv)
 
 	if ( debug ) NJB_Set_Debug(debug);
 
-	if ( NJB_Discover(njbs, 0, &n) == -1 ) {
-		njb_error_dump(stderr);
+	if (NJB_Discover(njbs, 0, &n) == -1) {
+	  fprintf(stderr, "could not locate any jukeboxes\n");
+	  return 1;
 	}
 
 	if ( n == 0 ) {
-		fprintf(stderr, "No NJB devices found\n");
-		return 1;
+	  fprintf(stderr, "No NJB devices found\n");
+	  return 1;
 	}
 
 	printf("Found %u devices.\n", n);
 	
 	for (i = 0; i < n; i++) {
 	  njb_keyval_t *key;
+	  int j;
 	  njb = &njbs[i];
+
 	  printf("Device %u: ", i+1);
 	  switch (njb->device_type)
 	    {
@@ -67,40 +69,48 @@ int main (int argc, char **argv)
 	    case NJB_DEVICE_NJBZENTOUCH:
 	      printf("\n    Jukebox type: Creative Jukebox Zen Touch\n");
 	      break;
+	    case NJB_DEVICE_NJBZENMICRO:
+	      printf("\n    Jukebox type: Creative Jukebox Zen Micro\n");
+	      break;
+	    case NJB_DEVICE_DELLDJ2:
+	      printf("\n    Jukebox type: Second Generation Dell DJ\n");
+	      break;
 	    default:
 	      printf("\n    Unknown jukebox type.\n");
 	    }
 
 	  njb= &njbs[i];
 
-	  if ( NJB_Open(njb) == -1 ) {
-	    njb_error_dump(stderr);
+	  if (NJB_Open(njb) == -1) {
+	    NJB_Error_Dump(njb, stderr);
 	    return 1;
 	  }
 
-	  if ((njbid = NJB_Ping(njb)) == NULL) {
-	    njb_error_dump(stderr);
-	    return 1;
+	  NJB_Ping(njb);
+	  
+	  printf("    Jukebox SDMI ID: ");
+	  for (j = 0; j < 16; j++) {
+	    printf("%02X", njb->njbid->id[j]);
 	  }
+	  printf("\n");
 
-	  printf("    Jukebox SDMI ID: %s\n", njb->idstring);
 
 	  if (njb->device_type == NJB_DEVICE_NJB1) {
-	    printf("    Firmware: %u.%u\n", njb->fwMajor, 
-		   njb->fwMinor);
+	    printf("    Firmware: %u.%u\n", njb->njbid->fwMajor, 
+		   njb->njbid->fwMinor);
 	  }
 	  else {
-	    printf("    Firmware: %u.%u.%u\n", njbid->fwMajor, 
-		   njbid->fwMinor, njbid->fwRel);
-	    printf("    Hardware: %u.%u.%u\n", njbid->hwMajor, 
-		   njbid->hwMinor, njbid->hwRel);
+	    printf("    Firmware: %u.%u.%u\n", njb->njbid->fwMajor, 
+		   njb->njbid->fwMinor, njb->njbid->fwRel);
+	    printf("    Hardware: %u.%u.%u\n", njb->njbid->hwMajor, 
+		   njb->njbid->hwMinor, njb->njbid->hwRel);
 	  }
 	  
-	  printf("    Product name: %s\n", njbid->productName);
+	  printf("    Product name: %s\n", njb->njbid->productName);
 	  
 	  /* This doesn't exist (apparently) on NJB3 */
 	  if (njb->device_type == NJB_DEVICE_NJB1) {
-	    printf("    Power connected: %s\n", njbid->power ? "yes":"no");
+	    printf("    Power connected: %s\n", njb->njbid->power ? "yes":"no");
 	  }
 
 	  key = NJB_Get_Keys(njb);
@@ -110,8 +120,6 @@ int main (int argc, char **argv)
 	  }
 	  
 	  
-	  free(njbid);
-	  
 	  NJB_Close(njb);
 
 	}
